@@ -42,6 +42,15 @@ OC.L10N.register(
     "Deck" : "Kartaro",
     "Changes in the <strong>Deck app</strong>" : "Ŝanĝoj en la <strong>aplikaĵo Kartaro</strong>",
     "A <strong>comment</strong> was created on a card" : "<strong>Komento</strong> kreiĝis sur karton",
+    "The file was uploaded" : "La dosiero alŝutiĝis",
+    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "La dosiero alŝutita superas la regulon „upload_max_filesize“ el „php.ini“",
+    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "La dosiero alŝutita superas la regulon „MAX_FILE_SIZE“ specifita en la HTML-formularo",
+    "The file was only partially uploaded" : "La dosiero alŝutiĝis nur parte",
+    "No file was uploaded" : "Neniu dosiero alŝutiĝis",
+    "Missing a temporary folder" : "Mankas provizora dosierujo",
+    "Could not write file to disk" : "Ne eblis skribi dosieron sur diskon",
+    "A PHP extension stopped the file upload" : "PHP-modulo haltigis la dosieralŝuton",
+    "No file uploaded or file size exceeds maximum of %s" : "Neniu dosiero alŝutita, aŭ dosiergrando transpasas la maksimumon %s",
     "The card \"%s\" on \"%s\" has been assigned to you by %s." : "La karto „%s“ sur „%s“ estis atribuita al vi de %s.",
     "The card \"%s\" on \"%s\" has reached its due date." : "La karto „%s“ sur „%s“ atingis sian limdaton.",
     "%s has mentioned you in a comment on \"%s\"." : "%s menciis vin en komento ĉe „%s“.",
@@ -54,15 +63,8 @@ OC.L10N.register(
     "Later" : "Poste",
     "copy" : "kopio",
     "Done" : "Farita",
-    "The file was uploaded" : "La dosiero alŝutiĝis",
-    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "La dosiero alŝutita superas la regulon „upload_max_filesize“ el „php.ini“",
-    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "La dosiero alŝutita superas la regulon „MAX_FILE_SIZE“ specifita en la HTML-formularo",
-    "The file was only partially uploaded" : "La dosiero alŝutiĝis nur parte",
-    "No file was uploaded" : "Neniu dosiero alŝutiĝis",
-    "Missing a temporary folder" : "Mankas provizora dosierujo",
-    "Could not write file to disk" : "Ne eblis skribi dosieron sur diskon",
-    "A PHP extension stopped the file upload" : "PHP-modulo haltigis la dosieralŝuton",
-    "No file uploaded or file size exceeds maximum of %s" : "Neniu dosiero alŝutita, aŭ dosiergrando transpasas la maksimumon %s",
+    "Attachments" : "Dosieraj aldonaĵoj",
+    "File" : "Dosiero",
     "Invalid date, date format must be YYYY-MM-DD" : "Nevalida dato; datoformo estu JJJJ-MM-TT",
     "Select the board to link to a project" : "Elekti la tabulon ligotan al projekto",
     "Select board" : "Elekti tabulon",
@@ -91,20 +93,19 @@ OC.L10N.register(
     "Edit" : "Redakti",
     "Members" : "Membroj",
     "Download" : "Elŝuti",
-    "Attachments" : "Dosieraj aldonaĵoj",
-    "Comments" : "Komentoj",
     "Modified" : "Modifita",
     "Created" : "Kreita",
+    "Comments" : "Komentoj",
     "Save" : "Konservi",
+    "Created:" : "Kreita:",
     "Reply" : "Respondi",
     "Update" : "Ĝisdatigi",
-    "Created:" : "Kreita:",
     "Description" : "Priskribo",
     "Formatting help" : "Helpo pri tekstaranĝo",
+    "Select Date" : "Elekti daton",
     "Remove due date" : "Viŝi limdaton",
     "Unarchive card" : "Malarĥivigi karton",
     "Archive card" : "Arĥivigi karton",
-    "Select Date" : "Elekti daton",
     "(group)" : "(grupo)",
     "Delete card" : "Forigi karton",
     "seconds ago" : "antaŭ kelkaj sekundoj",
@@ -112,18 +113,20 @@ OC.L10N.register(
     "Search" : "Serĉi",
     "Archived boards" : "Arĥivigitaj tabuloj",
     "Shared with you" : "Kunhavata kun vi",
+    "An error occurred" : "Eraro okazis",
     "Edit board" : "Modifi tabulon",
     "Unarchive board" : "Elarĥivigi tabulon",
     "Archive board" : "Enarĥivigi tabulon",
     "No notifications" : "Neniu sciigo",
     "Delete board" : "Forigi tabulon",
-    "An error occurred" : "Eraro okazis",
     "Advanced options" : "Detalaj agordoj",
+    "Export" : "Eksporti",
     "Today" : "Hodiaŭ",
     "Tomorrow" : "Morgaŭ",
     "Close" : "Malfermi",
     "Link to a board" : "Ligilo al tabulo",
     "Maximum file size of {size} exceeded" : "Maksimuma dosiergrando {size} transpasita",
+    "Due date" : "Limdato",
     "Error creating the share" : "Eraro dum kreo de la kunhavigo",
     "Share" : "Kunhavigi",
     "Personal" : "Persona",
