@@ -1,16 +1,17 @@
 OC.L10N.register(
     "deck",
     {
-    "Personal" : "Personal",
+    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Le file incargate excede le directiva MAX_FILE_SIZE que esseva specificate in le formulario HTML",
+    "No file was uploaded" : "Nulle file esseva incargate",
+    "Missing a temporary folder" : "Il manca un dossier temporari",
     "Finished" : "Finite",
     "To review" : "A revider",
     "Action needed" : "Action necessari",
     "Later" : "Depost",
     "Done" : "Preste",
-    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Le file incargate excede le directiva MAX_FILE_SIZE que esseva specificate in le formulario HTML",
-    "No file was uploaded" : "Nulle file esseva incargate",
-    "Missing a temporary folder" : "Il manca un dossier temporari",
+    "Attachments" : "Attachamentos",
     "Cancel" : "Cancellar",
+    "Completed" : "Completate",
     "Details" : "Detalios",
     "Sharing" : "Compartente",
     "Tags" : "Etiquettas",
@@ -23,22 +24,26 @@ OC.L10N.register(
     "Edit" : "Modificar",
     "Members" : "Membros",
     "Download" : "Discargar",
-    "Attachments" : "Attachamentos",
-    "Comments" : "Commentarios",
     "Modified" : "Modificate",
+    "Comments" : "Commentarios",
     "Save" : "Salveguardar",
+    "Created:" : "Create:",
     "Reply" : "Responder",
     "Update" : "Actualisation",
-    "Created:" : "Create:",
     "Description" : "Description",
-    "Completed" : "Completate",
     "(group)" : "(gruppo)",
     "seconds ago" : "secundas passate",
+    "Keyboard shortcuts" : "Combinationes de claves",
+    "Keyboard shortcut" : "Combination de claves",
+    "Search" : "Cercar",
     "Shared with you" : "Compartite con te",
     "No notifications" : "Nulle notificationes",
+    "Advanced options" : "Optiones avantiate",
+    "Export" : "Exportar",
     "Today" : "Hodie",
     "Tomorrow" : "Deman",
     "Close" : "Clauder",
-    "Share" : "Compartir"
+    "Share" : "Compartir",
+    "Personal" : "Personal"
 },
 "nplurals=2; plural=(n != 1);");
