@@ -2,6 +2,10 @@ OC.L10N.register(
     "deck",
     {
     "Deck" : "დასტა",
+    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "ატვირთული ფაილი აჭარბებს php.ini-ში დაყენებულ upload_max_filesize დირექტივას",
+    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "ატვირთული ფაილი აჭარბებს HTML ფორამაში მითითებულ MAX_FILE_SIZE დირექტივას",
+    "No file was uploaded" : "ფაილი არ აიტვირთა",
+    "Missing a temporary folder" : "დროებითი დირექტორია არ არსებობს",
     "The card \"%s\" on \"%s\" has reached its due date." : "ბარათმა \"%s\" \"%s\"-ზე მიაღწია დანიშნულ დროს.",
     "The board \"%s\" has been shared with you by %s." : "დაფა \"%s\" თქვენთან გაზიარდა %s-ისთვის.",
     "%s on %s" : "%s %s-ზე",
@@ -10,10 +14,7 @@ OC.L10N.register(
     "Action needed" : "საჭიროა ქმედება",
     "Later" : "მოგვიანებით",
     "Done" : "დასრულებულია",
-    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "ატვირთული ფაილი აჭარბებს php.ini-ში დაყენებულ upload_max_filesize დირექტივას",
-    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "ატვირთული ფაილი აჭარბებს HTML ფორამაში მითითებულ MAX_FILE_SIZE დირექტივას",
-    "No file was uploaded" : "ფაილი არ აიტვირთა",
-    "Missing a temporary folder" : "დროებითი დირექტორია არ არსებობს",
+    "File" : "ფაილი",
     "Invalid date, date format must be YYYY-MM-DD" : "არასწორი თარიღი, თარიღის ფორმატი უნდა იყოს წწწწ-თთ-დდ",
     "Cancel" : "უარყოფა",
     "File already exists" : "ფაილი უკვე არსებობს",
@@ -35,13 +36,13 @@ OC.L10N.register(
     "Edit" : "შეცვლა",
     "Members" : "წევრები",
     "Download" : "ჩამოტვირთვა",
-    "Comments" : "კომენტარები",
     "Modified" : "შეიცვალა",
     "Created" : "შექმნილია",
+    "Comments" : "კომენტარები",
     "Save" : "შენახვა",
+    "Created:" : "შექმნილია:",
     "Reply" : "პასუხი",
     "Update" : "განახლება",
-    "Created:" : "შექმნილია:",
     "Description" : "აღწერა",
     "Formatting help" : "დახმარება ფორმატირებაზე",
     "Remove due date" : "მოაშორეთ დანიშნულების დრო",
@@ -60,9 +61,11 @@ OC.L10N.register(
     "No notifications" : "შეტყობინებები არაა",
     "Delete board" : "დაფის გაუქმება",
     "Advanced options" : "დამატებითი ოპციონები",
+    "Export" : "ექსპორტი",
     "Today" : "დღეს",
     "Tomorrow" : "ხვალ",
     "Close" : "დახურვა",
+    "Due date" : "განპირობებულია თარიღისთვის",
     "Share" : "გაზიარება",
     "Personal" : "პირადი"
 },
