@@ -64,6 +64,15 @@ OC.L10N.register(
     "Deck" : "Darbai",
     "Changes in the <strong>Deck app</strong>" : "Pakeitimai <strong>Darbų programėlėje</strong>",
     "A <strong>comment</strong> was created on a card" : "Kortelėje buvo sukurtas <strong>komentaras</strong>",
+    "The file was uploaded" : "Failas buvo įkeltas",
+    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Įkeliamas failas viršija upload_max_filesize direktyvą, esančią faile php.ini",
+    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Įkeltas failas viršija MAX_FILE_SIZE direktyvą, kuri buvo nurodyta HTML formoje",
+    "The file was only partially uploaded" : "Failas buvo tik dalinai įkeltas",
+    "No file was uploaded" : "Nebuvo įkeltas joks failas",
+    "Missing a temporary folder" : "Trūksta laikinojo aplanko",
+    "Could not write file to disk" : "Nepavyko įrašyti failą į diską",
+    "A PHP extension stopped the file upload" : "PHP plėtinys sustabdė failo įkėlimą",
+    "No file uploaded or file size exceeds maximum of %s" : "Neįkeltas joks failas arba failo dydis viršija maksimalų %s dydį",
     "Upcoming cards" : "Artėjančios kortelės",
     "Load more" : "Įkelti daugiau",
     "The card \"%s\" on \"%s\" has been assigned to you by %s." : "Kortelę \"%s\" ties \"%s\" priskyrė jums %s.",
@@ -79,15 +88,8 @@ OC.L10N.register(
     "Later" : "Vėliau",
     "copy" : "kopija",
     "Done" : "Atlikta",
-    "The file was uploaded" : "Failas buvo įkeltas",
-    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Įkeliamas failas viršija upload_max_filesize direktyvą, esančią faile php.ini",
-    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Įkeltas failas viršija MAX_FILE_SIZE direktyvą, kuri buvo nurodyta HTML formoje",
-    "The file was only partially uploaded" : "Failas buvo tik dalinai įkeltas",
-    "No file was uploaded" : "Nebuvo įkeltas joks failas",
-    "Missing a temporary folder" : "Trūksta laikinojo aplanko",
-    "Could not write file to disk" : "Nepavyko įrašyti failą į diską",
-    "A PHP extension stopped the file upload" : "PHP plėtinys sustabdė failo įkėlimą",
-    "No file uploaded or file size exceeds maximum of %s" : "Neįkeltas joks failas arba failo dydis viršija maksimalų %s dydį",
+    "Attachments" : "Priedai",
+    "File" : "Failas",
     "Card not found" : "Kortelė nerasta",
     "Path is already shared with this card" : "Kelias jau yra bendrinamas su šia kortele",
     "Invalid date, date format must be YYYY-MM-DD" : "Netinkama data, datos formatas privalo būti MMMM-mm-dd",
@@ -185,7 +187,6 @@ OC.L10N.register(
     "The title cannot be empty." : "Pavadinimas negali būti tuščias.",
     "Open in sidebar view" : "Atverti šoninės juostos rodinyje",
     "Open in bigger view" : "Atverti didesniame rodinyje",
-    "Attachments" : "Priedai",
     "Comments" : "Komentarai",
     "Failed to load comments" : "Nepavyko įkelti komentarų",
     "No comments yet. Begin the discussion!" : "Kol kas komentarų nėra. Pradėkite diskusiją!",
@@ -257,6 +258,8 @@ OC.L10N.register(
     "Advanced options" : "Išplėstinės parinktys",
     "Restore archived cards" : "Atkurti archyvuotas korteles",
     "Clone" : "Dubliuoti",
+    "Export as CSV" : "Eksportuoti kaip CSV",
+    "Export" : "Eksportuoti",
     "Today" : "Šiandien",
     "Tomorrow" : "Rytoj",
     "No due" : "Be galutinio termino",
@@ -277,6 +280,7 @@ OC.L10N.register(
     "Create a card" : "Sukurti kortelę",
     "Something went wrong" : "Kažkas nutiko",
     "Maximum file size of {size} exceeded" : "Viršytas maksimalus {size} failo dydis",
+    "Due date" : "Galutinio termino data",
     "Error creating the share" : "Klaida kuriant viešinį",
     "Share" : "Bendrinti",
     "Personal" : "Asmeniniai",
