@@ -66,6 +66,15 @@ OC.L10N.register(
     "Deck" : "Deck",
     "Changes in the <strong>Deck app</strong>" : "Промени во <strong>апликацијата Deck</strong>",
     "A <strong>comment</strong> was created on a card" : "<strong>Коментар</strong> е креиран на картица",
+    "The file was uploaded" : "Датотеката е прикачена",
+    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Подигнатата датотека ја надминува upload_max_filesize директивата во php.ini",
+    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Големината на датотеката ја надминува MAX_FILE_SIZE директивата која беше специфицирана во HTML формата",
+    "The file was only partially uploaded" : "Датотеката беше само делумно прикачена",
+    "No file was uploaded" : "Нема прикачено дадотека",
+    "Missing a temporary folder" : "Недостасува привремена папка",
+    "Could not write file to disk" : "Неможе да се запишува на дискот",
+    "A PHP extension stopped the file upload" : "PHP додаток го стопираше прикачувањето на датотеката",
+    "No file uploaded or file size exceeds maximum of %s" : "Нема прикачена дадотека или големината го надмминува максимумот од %s",
     "Upcoming cards" : "Престојни картици",
     "Load more" : "Вчитај повеќе",
     "The card \"%s\" on \"%s\" has been assigned to you by %s." : "Картицата \"%s\" на \"%s\" ти е доделена од %s.",
@@ -80,21 +89,14 @@ OC.L10N.register(
     "copy" : "копирај",
     "To Do" : "За правење",
     "Done" : "Готово",
-    "The file was uploaded" : "Датотеката е прикачена",
-    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Подигнатата датотека ја надминува upload_max_filesize директивата во php.ini",
-    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Големината на датотеката ја надминува MAX_FILE_SIZE директивата која беше специфицирана во HTML формата",
-    "The file was only partially uploaded" : "Датотеката беше само делумно прикачена",
-    "No file was uploaded" : "Нема прикачено дадотека",
-    "Missing a temporary folder" : "Недостасува привремена папка",
-    "Could not write file to disk" : "Неможе да се запишува на дискот",
-    "A PHP extension stopped the file upload" : "PHP додаток го стопираше прикачувањето на датотеката",
-    "No file uploaded or file size exceeds maximum of %s" : "Нема прикачена дадотека или големината го надмминува максимумот од %s",
+    "Attachments" : "Прилози",
+    "File" : "Датотека",
     "Card not found" : "Картицата не е пронајдена",
     "Path is already shared with this card" : "Патеката веќе е споделена со оваа картица",
     "Invalid date, date format must be YYYY-MM-DD" : "Невалиден датум, форматот мора да биде ГГГГ-ММ-ДД",
     "Personal planning and team project organization" : "Персонален планер и тимски проект организер",
-    "Card details" : "Детали за картица",
     "Add board" : "Додади табла",
+    "Card details" : "Детали за картица",
     "Select the board to link to a project" : "Избери табла за поврзување со проект",
     "Search by board title" : "Барај по име на табла",
     "Select board" : "Избери табла",
@@ -102,21 +104,22 @@ OC.L10N.register(
     "No lists available" : "Нема достапни листи",
     "Select a list" : "Избери листа",
     "Move card" : "Премести картица",
-    "Select a card" : "Избери картица",
-    "Cancel" : "Откажи",
     "Select the card to link to a project" : "Избери картица за поврзување со проект",
     "Link to card" : "Линк до картица",
+    "Select a card" : "Избери картица",
+    "Cancel" : "Откажи",
+    "This board is read only" : "Оваа табла е само за читање",
+    "Drop your files to upload" : "Повлечи датотеки за да прикачите",
     "File already exists" : "Датотека веќе постои",
     "A file with the name {filename} already exists." : "Датотека со име {filename} веќе постои.",
     "Do you want to overwrite it?" : "Дали сакате да го пребришете?",
     "Overwrite file" : "Пребриши датотека",
     "Keep existing file" : "Зачувај ја постоечката датотека",
-    "This board is read only" : "Оваа табла е само за читање",
-    "Drop your files to upload" : "Повлечи датотеки за да прикачите",
     "Add card" : "Додади картица",
     "Archived cards" : "Архивирани картици",
     "Add list" : "Додади листа",
     "List name" : "Име на листа",
+    "Active filters" : "Активни филтри",
     "Apply filter" : "Додади филтер",
     "Filter by tag" : "Филтрирај по ознака",
     "Filter by assigned user" : "Филтрирај по назначени корисници",
@@ -145,6 +148,8 @@ OC.L10N.register(
     "Deleted lists" : "Избришани листи",
     "Undo" : "Врати",
     "Deleted cards" : "Избришани картици",
+    "Failed to create share with {displayName}" : "Неможе да се сподели со {displayName}",
+    "Transfer" : "Трансфер",
     "No participants found" : "Не се пронајдени учесници",
     "Board owner" : "Сопственик на таблата",
     "(Group)" : "(Група)",
@@ -153,20 +158,20 @@ OC.L10N.register(
     "Can manage" : "Може да ја менаџира",
     "Owner" : "Сопственик",
     "Delete" : "Избриши",
-    "Failed to create share with {displayName}" : "Неможе да се сподели со {displayName}",
-    "Transfer" : "Трансфер",
+    "List deleted" : "Листата е избришана",
     "Archive all cards" : "Архивирај ги сите картици",
     "Delete list" : "Избриши листа",
     "Archive all cards in this list" : "Архивирај ги сите картици во листата",
     "Add a new card" : "Додади нова картица",
     "Card name" : "Име на картицата",
-    "List deleted" : "Листата е избришана",
+    "title and color value must be provided" : "наслов и боја мора да се приложи",
     "Edit" : "Уреди",
     "Add a new tag" : "Додади нова ознака",
-    "title and color value must be provided" : "наслов и боја мора да се приложи",
     "Board name" : "Име на табла",
     "Members" : "Членови",
     "Assign a user to this card…" : "Додели корисник на оваа картица...",
+    "File to share" : "Датотека за споделување",
+    "Invalid path selected" : "Избрана невалидна патека",
     "Upload new files" : "Прикачи нови датотеки",
     "Share from Files" : "Сподели од датотеките",
     "Add this attachment" : "Додади го овој прилог",
@@ -174,23 +179,21 @@ OC.L10N.register(
     "Download" : "Преземи",
     "Delete Attachment" : "Избриши прилог",
     "Restore Attachment" : "Врати прилог",
-    "File to share" : "Датотека за споделување",
-    "Invalid path selected" : "Избрана невалидна патека",
-    "Open in sidebar view" : "Отвори страничен поглед",
-    "Open in bigger view" : "Отвори на голем екран",
-    "Attachments" : "Прилози",
-    "Comments" : "Коментари",
     "Modified" : "Изменето",
     "Created" : "Креирано",
     "The title cannot be empty." : "Насловот неможе да биде празен.",
+    "Open in sidebar view" : "Отвори страничен поглед",
+    "Open in bigger view" : "Отвори на голем екран",
+    "Comments" : "Коментари",
     "No comments yet. Begin the discussion!" : "Сеуште нема коментари. Започни дискусија!",
-    "Save" : "Зачувај",
     "The comment cannot be empty." : "Коментарот неможе да биде празен.",
     "The comment cannot be longer than 1000 characters." : "Коментарот неможе да биде поголем од 1000 карактери.",
+    "Save" : "Зачувај",
+    "Created:" : "Создадено:",
     "In reply to" : "Како одговор на",
     "Reply" : "Одговор",
     "Update" : "Ажурирај",
-    "Created:" : "Создадено:",
+    "Write a description …" : "Напиши опис ...",
     "Description" : "Опис",
     "(Unsaved)" : "(Незачувано)",
     "(Saving…)" : "(Снимање…)",
@@ -198,21 +201,22 @@ OC.L10N.register(
     "Edit description" : "Измени опис",
     "View description" : "Види опис",
     "Add Attachment" : "Додади прилог",
-    "Write a description …" : "Напиши опис ...",
     "Choose attachment" : "Избери прилог",
+    "Select Date" : "Избери датум",
+    "Later today – {timeLocale}" : "Денес покасно – {timeLocale}",
+    "Tomorrow – {timeLocale}" : "Утре – {timeLocale}",
     "Set a due date" : "Постави краен рок",
     "Remove due date" : "Отстрани краен рок",
     "Mark as done" : "Означи како готово",
     "Unarchive card" : "Врати картица од архива",
     "Archive card" : "Архивирај картица",
-    "Select Date" : "Избери датум",
     "Assign a tag to this card…" : "Додади ознака на оваа картица...",
     "(group)" : "(group)",
+    "Card deleted" : "Картицата е избришана",
     "Edit title" : "Удери наслов",
     "Assign to me" : "Доделени мене",
     "Unassign myself" : "Откажи се",
     "Delete card" : "Избриши картица",
-    "Card deleted" : "Картицата е избришана",
     "seconds ago" : "пред неколку секунди",
     "Keyboard shortcuts" : "Кратенки преку тастатура",
     "Keyboard shortcut" : "Кратенка преку тастатура",
@@ -226,6 +230,12 @@ OC.L10N.register(
     "Use bigger card view" : "Користи поголем преглед на картици",
     "Show boards in calendar/tasks" : "Прикажи ги таблите во календарнот",
     "Cancel edit" : "Откажи ажурирање",
+    "Board {0} deleted" : "Таблата {0} е избришана",
+    "All cards" : "Сите картици",
+    "Only assigned cards" : "Само доделени картици",
+    "No reminder" : "Нема потсетник",
+    "An error occurred" : "Настана грешка",
+    "Delete the board?" : "Бришење на таблата?",
     "Board details" : "Детали за таблата",
     "Edit board" : "Измени табла",
     "Clone board" : "Клонирај табла",
@@ -234,33 +244,26 @@ OC.L10N.register(
     "Turn on due date reminders" : "Вклучи потсетници за крајните рокови",
     "Turn off due date reminders" : "Исклучи потсетници за крајните рокови",
     "Due date reminders" : "Потсетници за крајните рокови",
-    "All cards" : "Сите картици",
     "Assigned cards" : "Доделени картици",
     "No notifications" : "Нема известувања",
     "Delete board" : "Избриши табла",
-    "Board {0} deleted" : "Таблата {0} е избришана",
-    "Only assigned cards" : "Само доделени картици",
-    "No reminder" : "Нема потсетник",
-    "An error occurred" : "Настана грешка",
-    "Delete the board?" : "Бришење на таблата?",
     "Clone cards" : "Клинирај картици",
     "Advanced options" : "Напредни опции",
     "Clone" : "Клонирај",
+    "Export" : "Извези",
     "Loading filtered view" : "Вчитување на филтриран поглед",
     "Today" : "Денес",
     "Tomorrow" : "Утре",
     "No due" : "Не истекува",
     "No results found" : "Нема пронајдено резултати",
     "{stack} in {board}" : "{stack} во {board}",
+    "Create card" : "Креирајте картица",
     "Create a new card" : "Креирајте нова картица",
     "Card title" : "Наслов на картицата",
-    "Create card" : "Креирајте картица",
     "Open card" : "Отвори картица",
     "Close" : "Затвори",
     "No upcoming cards" : "Нема престојни картици",
     "upcoming cards" : "престојни картици",
-    "Tomorrow – {timeLocale}" : "Утре – {timeLocale}",
-    "Later today – {timeLocale}" : "Денес покасно – {timeLocale}",
     "Link to a board" : "Линк до табла",
     "Link to a card" : "Линк до картица",
     "Create a card" : "Креирајте картица",
@@ -268,6 +271,7 @@ OC.L10N.register(
     "Something went wrong" : "Нешто не е во ред",
     "Failed to upload {name}" : "Неуспешно прикачување {name}",
     "Maximum file size of {size} exceeded" : "Максималната големина на датотека од {size} е достигната",
+    "Due date" : "До датум",
     "Error creating the share" : "Грешка при креирање на споделување",
     "Share with a Deck card" : "Споделено со Deck картица",
     "Share {file} with a Deck card" : "Сподели {file} со Deck картица",
