@@ -8,6 +8,7 @@ OC.L10N.register(
     "Later" : "Хойшлуулах",
     "copy" : "Хуулах ",
     "Done" : "Хийсэн",
+    "Attachments" : "Хавсралт",
     "Cancel" : "болиулах",
     "Open" : "Нээх",
     "Completed" : "Гүйцэтгэгдсэн",
@@ -25,14 +26,13 @@ OC.L10N.register(
     "Edit" : "Засварлах",
     "Members" : "Гишүүд",
     "Download" : "Татах",
-    "Attachments" : "Хавсралт",
-    "Comments" : "Сэтгэгдлүүд",
     "Modified" : "Өөрчлөгдсөн",
     "Created" : "Үүсгэсэн",
+    "Comments" : "Сэтгэгдлүүд",
     "Save" : "Хадгалах",
+    "Created:" : "Үүсгэсэн:",
     "Reply" : "хариулт",
     "Update" : "Шинэчлэх",
-    "Created:" : "Үүсгэсэн:",
     "Description" : "Тайлбар",
     "(group)" : "(бүлэг)",
     "seconds ago" : "хоёрдахь өмнө",
@@ -41,9 +41,9 @@ OC.L10N.register(
     "Shared with you" : "тантай хуваалцсан",
     "No notifications" : "Мэдэгдэл байхгүй",
     "Advanced options" : "Бусад сонголтууд",
+    "Export" : "Экспорт",
     "Today" : "өнөөдөр",
     "Tomorrow" : "маргааш",
-    "Close" : "Хаах",
     "Share" : "Түгээх",
     "Personal" : "Хувийн"
 },
