@@ -66,6 +66,15 @@ OC.L10N.register(
     "Deck" : "Deck",
     "Changes in the <strong>Deck app</strong>" : "Càmbios in <strong> s'aplicatzione Deck</strong>",
     "A <strong>comment</strong> was created on a card" : "Unu <strong>cummentu</strong> est istadu creadu in s'ischeda",
+    "The file was uploaded" : "S'archìviu est istadu carrigadu",
+    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "S'archìviu carrigadu superat sa diretiva upload_max_filesize in php.ini",
+    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "S'archìviu carrigadu superat sa diretiva MAX_FILE_SIZE ispetzificada in su mòdulu HTML",
+    "The file was only partially uploaded" : "Isceti una parte de s'archìviu est carrigada",
+    "No file was uploaded" : "Perunu archìviu carrigadu",
+    "Missing a temporary folder" : "Mancat una cartella temporànea",
+    "Could not write file to disk" : "No at fatu a iscrìere s'archìviu in su discu",
+    "A PHP extension stopped the file upload" : "Un'estensione PHP at firmadu su carrigamentu de s'archìviu",
+    "No file uploaded or file size exceeds maximum of %s" : "Perun'archìviu carrigadu o sa mannària de s'archìviu superat su màssimu de %s",
     "Upcoming cards" : "Ischedas imbenientes",
     "Load more" : "Càrriga àteru",
     "The card \"%s\" on \"%s\" has been assigned to you by %s." : "S'ischeda \"%s\" in \"%s\" s'est istadu assignadu dae %s.",
@@ -87,21 +96,14 @@ OC.L10N.register(
     "copy" : "còpia",
     "To Do" : "De fàghere",
     "Done" : "Fatu",
-    "The file was uploaded" : "S'archìviu est istadu carrigadu",
-    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "S'archìviu carrigadu superat sa diretiva upload_max_filesize in php.ini",
-    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "S'archìviu carrigadu superat sa diretiva MAX_FILE_SIZE ispetzificada in su mòdulu HTML",
-    "The file was only partially uploaded" : "Isceti una parte de s'archìviu est carrigada",
-    "No file was uploaded" : "Perunu archìviu carrigadu",
-    "Missing a temporary folder" : "Mancat una cartella temporànea",
-    "Could not write file to disk" : "No at fatu a iscrìere s'archìviu in su discu",
-    "A PHP extension stopped the file upload" : "Un'estensione PHP at firmadu su carrigamentu de s'archìviu",
-    "No file uploaded or file size exceeds maximum of %s" : "Perun'archìviu carrigadu o sa mannària de s'archìviu superat su màssimu de %s",
+    "Attachments" : "Alligongiados",
+    "File" : "Archìviu",
     "Card not found" : "Ischeda no agatada",
     "Path is already shared with this card" : "Su caminu est giai cumpartzidu cun cust'ischeda",
     "Invalid date, date format must be YYYY-MM-DD" : "Data non bàlida, su formadu de sa data depet èssere AAAA-MM-GG",
     "Personal planning and team project organization" : "Pranificatzione personale e organizatzione de su progetu de iscuadra",
-    "Card details" : "Detàllios ischeda",
     "Add board" : "Agiunghe lavagna",
+    "Card details" : "Detàllios ischeda",
     "Select the board to link to a project" : "Seletziona lavagna de collegare a unu progetu",
     "Search by board title" : "Chirca dae su tìtulu de sa lavagna",
     "Select board" : "Seletziona lavagna",
@@ -109,17 +111,17 @@ OC.L10N.register(
     "No lists available" : "Perunu elencu a disponimentu",
     "Select a list" : "Seletziona un'elencu",
     "Move card" : "Tràmuda ischeda",
-    "Select a card" : "Seletziona un'ischeda",
-    "Cancel" : "Annulla",
     "Select the card to link to a project" : "Seletzioan s'ischeda de collegare a unu progetu",
     "Link to card" : "Collega a un'ischeda",
+    "Select a card" : "Seletziona un'ischeda",
+    "Cancel" : "Annulla",
+    "This board is read only" : "Custa lavagna est isceti pro lèghere",
+    "Drop your files to upload" : "Lassa is archìvios pro ddos carrigare",
     "File already exists" : "Custu archìviu ddoe est giai",
     "A file with the name {filename} already exists." : "B'at giai un'archìviu cun su nùmene de {filename}.",
     "Do you want to overwrite it?" : "Ddu cheres subraiscrìere? ",
     "Overwrite file" : "Subraiscrie archìviu",
     "Keep existing file" : "Mantene s'archìviu chi ddoe est",
-    "This board is read only" : "Custa lavagna est isceti pro lèghere",
-    "Drop your files to upload" : "Lassa is archìvios pro ddos carrigare",
     "Add card" : "Agiunghe ischeda",
     "Archived cards" : "Ischedas archiviadas",
     "Add list" : "Agiunghe elencu",
@@ -152,6 +154,8 @@ OC.L10N.register(
     "Deleted lists" : "Elencos cantzellados",
     "Undo" : "Annulla",
     "Deleted cards" : "Ischeda cantzellada",
+    "Failed to create share with {displayName}" : "No at fatu a creare cumpartzidura cun {displayName}",
+    "Transfer" : "Tràmuda",
     "No participants found" : "Perunu partetzipante agatadu",
     "Board owner" : "Mere lavagna",
     "(Group)" : "(Grupu)",
@@ -160,20 +164,20 @@ OC.L10N.register(
     "Can manage" : "Faghet a gestire",
     "Owner" : "Mere",
     "Delete" : "Cantzella",
-    "Failed to create share with {displayName}" : "No at fatu a creare cumpartzidura cun {displayName}",
-    "Transfer" : "Tràmuda",
+    "List deleted" : "Elencu cantzelladu",
     "Archive all cards" : "Archìvia totu is ischedas",
     "Delete list" : "Cantzella elencu",
     "Archive all cards in this list" : "Archìvia totu is ischedas in cust'elencu",
     "Add a new card" : "Agiùnghe un'ischeda noa",
     "Card name" : "Nùmene de s'ischeda",
-    "List deleted" : "Elencu cantzelladu",
+    "title and color value must be provided" : "tocat de frunire su tìtulu e su balore de su colore",
     "Edit" : "Modìfica ",
     "Add a new tag" : "Agiunghe un'eticheta noa",
-    "title and color value must be provided" : "tocat de frunire su tìtulu e su balore de su colore",
     "Board name" : "Nùmene de sa lavagna",
     "Members" : "Membros",
     "Assign a user to this card…" : "Assigna utente a cust'ischeda...",
+    "File to share" : "Archìviu de cumpartzire",
+    "Invalid path selected" : "Percursu seletzionadu non bàlidu",
     "Upload new files" : "Càrriga archìvios noos",
     "Share from Files" : "Cumpartzi dae Archìvios",
     "Add this attachment" : "Agiunghe custu alligongiadu",
@@ -181,25 +185,23 @@ OC.L10N.register(
     "Download" : "Iscàrriga",
     "Delete Attachment" : "Cantzella alligongiadu",
     "Restore Attachment" : "Riprìstina alligongiadu",
-    "File to share" : "Archìviu de cumpartzire",
-    "Invalid path selected" : "Percursu seletzionadu non bàlidu",
-    "Open in sidebar view" : "Aberi in s'istanca laterale",
-    "Open in bigger view" : "Aberi in una bista prus ampra",
-    "Attachments" : "Alligongiados",
-    "Comments" : "Cummentos",
     "Modified" : "Modificadu",
     "Created" : "Creadu",
     "The title cannot be empty." : "Su tìtulu non podet èssere bòidu",
-    "No comments yet. Begin the discussion!" : "Perunu cummentu ancora. Cumintzat sa chistionada!",
+    "Open in sidebar view" : "Aberi in s'istanca laterale",
+    "Open in bigger view" : "Aberi in una bista prus ampra",
+    "Comments" : "Cummentos",
     "Failed to load comments" : "No at fatu a carrigare is cummentos",
-    "Save" : "Sarva",
+    "No comments yet. Begin the discussion!" : "Perunu cummentu ancora. Cumintzat sa chistionada!",
     "The comment cannot be empty." : "Su cummentu non podet èssere bòidu",
     "The comment cannot be longer than 1000 characters." : "Su cummentu non podet èssere prus longu de 1000 caràteres.",
+    "Save" : "Sarva",
+    "Created:" : "Creadu:",
     "In reply to" : "Rispondende a ",
     "Cancel reply" : "Annulla risposta",
     "Reply" : "Risponde",
     "Update" : "Agiorna",
-    "Created:" : "Creadu:",
+    "Write a description …" : "Iscrie una descritzione ...",
     "Description" : "Descritzione",
     "(Unsaved)" : "(Non sarvada)",
     "(Saving…)" : "(Sarbende…)",
@@ -207,23 +209,22 @@ OC.L10N.register(
     "Edit description" : "Modìfica descritzione",
     "View description" : "Visualiza descritzione",
     "Add Attachment" : "Agiunghe alligongiadu",
-    "Write a description …" : "Iscrie una descritzione ...",
     "Choose attachment" : "Sèbera un'alligongiadu",
+    "Select Date" : "Seletziona data",
     "Set a due date" : "Cunfigura data de iscadèntzia",
     "Remove due date" : "Boga s'iscadèntzia",
     "Mark as done" : "Marca comente cumpletadu",
     "Unarchive card" : "Ischeda no archiviada",
     "Archive card" : "Archìviu no archiviadu",
-    "Select Date" : "Seletziona data",
     "Assign a tag to this card…" : "Assigna un'eticheta a cust'ischeda...",
     "Create a new tag:" : "Crea un'eticheta noa:",
     "(group)" : "(grupu)",
     "{count} comments, {unread} unread" : "{count} cummentos, {unread} non lèghidos",
+    "Card deleted" : "Ischeda cantzellada",
     "Edit title" : "Modìfica tìtulu",
     "Assign to me" : "Assigna a mie",
     "Unassign myself" : "Annulla s'assignatzione a mie",
     "Delete card" : "Cantzella ischeda",
-    "Card deleted" : "Ischeda cantzellada",
     "seconds ago" : "segundos a immoe",
     "Keyboard shortcuts" : "Curtziadòrgios de tecladu",
     "Keyboard shortcut" : "Curtziadòrgiu de tecladu",
@@ -236,6 +237,12 @@ OC.L10N.register(
     "Use bigger card view" : "Imprea bista cun ischedas prus mannas",
     "Show boards in calendar/tasks" : "Mustra lavagnas in calendàriu/fainas",
     "Cancel edit" : "Annulla modìfica",
+    "Board {0} deleted" : "Lavagna {0} cantzellada",
+    "All cards" : "Totu is ischedas",
+    "Only assigned cards" : "Isceti ischedas assignadas",
+    "No reminder" : "Perunu apuntu",
+    "An error occurred" : "B'at àpidu un'errore",
+    "Delete the board?" : "Cheres cantzellare sa lavagna?",
     "Board details" : "Detàllios lavagna",
     "Edit board" : "Modìfica lavagna",
     "Clone board" : "Clona lavagna",
@@ -244,18 +251,13 @@ OC.L10N.register(
     "Turn on due date reminders" : "Allughe is notìficas pro ammentare is iscadèntzias",
     "Turn off due date reminders" : "Istuda is notìficas pro ammentare is iscadèntzias",
     "Due date reminders" : "Notìficas pro ammentare is iscadèntzias",
-    "All cards" : "Totu is ischedas",
     "Assigned cards" : "Ischedas assignadas",
     "No notifications" : "Peruna notìfica",
     "Delete board" : "Cantzella lavagna",
-    "Board {0} deleted" : "Lavagna {0} cantzellada",
-    "Only assigned cards" : "Isceti ischedas assignadas",
-    "No reminder" : "Perunu apuntu",
-    "An error occurred" : "B'at àpidu un'errore",
-    "Delete the board?" : "Cheres cantzellare sa lavagna?",
     "Clone cards" : "Clona ischeda",
     "Advanced options" : "Sèberos avantzados",
     "Clone" : "Clona",
+    "Export" : "Esporta",
     "Loading filtered view" : "Carrigamentu de sa bista cun su filtru",
     "Today" : "Oe",
     "Tomorrow" : "Cras",
@@ -263,9 +265,9 @@ OC.L10N.register(
     "Search for {searchQuery} in all boards" : "Chirca {searchQuery} in totu is lavagnas",
     "No results found" : "Perunu resurtadu agatadu",
     "{stack} in {board}" : "{stack} in {board}",
+    "Create card" : "Crea ischeda",
     "Create a new card" : "Crea un'ischeda noa",
     "Card title" : "Tìtulu ischeda",
-    "Create card" : "Crea ischeda",
     "Creating the new card …" : "Creende s'ischeda noa ...",
     "Card \"{card}\" was added to \"{board}\"" : "S'ischeda \"{card}\" est istada agiunta a \"{board}\"",
     "Open card" : "Aberi ischeda",
@@ -280,6 +282,7 @@ OC.L10N.register(
     "Something went wrong" : "Ddoe at àpidu un'errore",
     "Failed to upload {name}" : "No at fatu a agiornare {name}",
     "Maximum file size of {size} exceeded" : "Mannària màssima de s'archìviu de {size} superada",
+    "Due date" : "Data de fine",
     "Error creating the share" : "Errore in sa creatzione de sa cumpatzidura",
     "Share with a Deck card" : "Cumpartzi cun un'ischeda deck",
     "Share {file} with a Deck card" : "Cumpartzi {file} cun un'ischeda de deck",
