@@ -1,17 +1,17 @@
 OC.L10N.register(
     "deck",
     {
-    "Personal" : "පුද්ගලික",
-    "Later" : "පසුව",
-    "copy" : "පිටපත්",
-    "Example Task 3" : "උදාහරණ කාර්යය 3",
-    "Example Task 2" : "උදාහරණ කාර්යය 2",
-    "Example Task 1" : "උදාහරණ කාර්යය 1",
     "No file was uploaded" : "කිසිදු ගොනුවක් උඩුගත කර නොමැත",
     "Missing a temporary folder" : "තාවකාලික බහාලුමක් අස්ථානගත වී ඇත",
+    "Later" : "පසුව",
+    "copy" : "පිටපත්",
+    "Attachments" : "ඇමිණුම්",
+    "File" : "ගොනුව",
     "Cancel" : "අවලංගු කරන්න",
     "File already exists" : "ගොනුව දැනටමත් පවතී",
     "Add list" : "ලැයිස්තුව එකතු කරන්න",
+    "Open" : "විවෘත",
+    "Completed" : "සම්පුර්ණයි",
     "Details" : "විස්තර",
     "Activity" : "ක්‍රියාකාරකම",
     "Undo" : "පෙරසේ",
@@ -19,20 +19,21 @@ OC.L10N.register(
     "Owner" : "හිමිකරු",
     "Edit" : "සංස්කරණය",
     "Download" : "බාගන්න",
-    "Attachments" : "ඇමිණුම්",
     "Comments" : "අදහස්",
     "Save" : "සුරකින්න",
     "Reply" : "පිළිතුර",
     "Update" : "යාවත්කාල",
     "Description" : "විස්තරය",
-    "Completed" : "සම්පුර්ණයි",
     "Select Date" : "දිනය තෝරන්න",
     "seconds ago" : "තත්පර කිහිපයකට පෙර",
+    "Search" : "සොයන්න",
     "Today" : "අද",
     "Tomorrow" : "හෙට",
     "Close" : "වසන්න",
     "Share" : "බෙදාගන්න",
-    "Next week" : "ඊළඟ සතිය",
-    "Next month" : "ඊළඟ මාසය"
+    "Personal" : "පුද්ගලික",
+    "Example Task 3" : "උදාහරණ කාර්යය 3",
+    "Example Task 2" : "උදාහරණ කාර්යය 2",
+    "Example Task 1" : "උදාහරණ කාර්යය 1"
 },
 "nplurals=2; plural=(n != 1);");
