@@ -66,6 +66,15 @@ OC.L10N.register(
     "Deck" : "Deck",
     "Changes in the <strong>Deck app</strong>" : "Spremembe v programu <strong>Deck</strong>",
     "A <strong>comment</strong> was created on a card" : "Nalogi je dodana nova <strong>opomba</strong>",
+    "The file was uploaded" : "Datoteka je uspešno poslana.",
+    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Poslana datoteka presega določilo največje dovoljene velikosti v datoteki php.ini",
+    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Poslana datoteka presega velikost, ki je določena kot omejitev MAX_FILE_SIZE v zapisu HTML.",
+    "The file was only partially uploaded" : "Datoteka ni bila poslana v celoti",
+    "No file was uploaded" : "Datoteka ni bila poslana",
+    "Missing a temporary folder" : "Manjka začasna mapa",
+    "Could not write file to disk" : "Ni mogoče zapisati datoteke na disk",
+    "A PHP extension stopped the file upload" : "Razširitev PHP onemogoča pošiljanje datoteke",
+    "No file uploaded or file size exceeds maximum of %s" : "Ali ni poslane datoteke ali pa velikost datoteke presega omejitev %s",
     "Upcoming cards" : "Prihajajoče naloge",
     "Load more" : "Naloži več",
     "The card \"%s\" on \"%s\" has been assigned to you by %s." : "Nalogo »%s« na »%s« vam dodeli %s.",
@@ -87,15 +96,8 @@ OC.L10N.register(
     "copy" : "kopija",
     "To Do" : "Naloge",
     "Done" : "Končane naloge",
-    "The file was uploaded" : "Datoteka je uspešno poslana.",
-    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Poslana datoteka presega določilo največje dovoljene velikosti v datoteki php.ini",
-    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Poslana datoteka presega velikost, ki je določena kot omejitev MAX_FILE_SIZE v zapisu HTML.",
-    "The file was only partially uploaded" : "Datoteka ni bila poslana v celoti",
-    "No file was uploaded" : "Datoteka ni bila poslana",
-    "Missing a temporary folder" : "Manjka začasna mapa",
-    "Could not write file to disk" : "Ni mogoče zapisati datoteke na disk",
-    "A PHP extension stopped the file upload" : "Razširitev PHP onemogoča pošiljanje datoteke",
-    "No file uploaded or file size exceeds maximum of %s" : "Ali ni poslane datoteke ali pa velikost datoteke presega omejitev %s",
+    "Attachments" : "Priloge",
+    "File" : "Datoteka",
     "Card not found" : "Naloge ni mogoče najti",
     "Path is already shared with this card" : "Pot je že povezana s to nalogo",
     "Invalid date, date format must be YYYY-MM-DD" : "Neveljaven zapis časa; biti mora v zapisu YYYY-MM-DD",
@@ -194,7 +196,6 @@ OC.L10N.register(
     "The title cannot be empty." : "Polje naslova ne sme biti prazno.",
     "Open in sidebar view" : "Odpri v bočnem pogledu",
     "Open in bigger view" : "Odpri v povečanem pogledu",
-    "Attachments" : "Priloge",
     "Comments" : "Opombe",
     "Failed to load comments" : "Nalaganje opomb je spodletelo.",
     "No comments yet. Begin the discussion!" : "Ni še odzivov, bodite prvi!",
@@ -293,6 +294,8 @@ OC.L10N.register(
     "Clone cards" : "Kloniraj nalogo",
     "Advanced options" : "Napredne možnosti",
     "Clone" : "Kloniraj",
+    "Export as CSV" : "Izvozi v zapis CSV",
+    "Export" : "Izvozi",
     "Loading filtered view" : "Poteka nalaganje filtriranega pogleda",
     "Today" : "Danes",
     "Tomorrow" : "Jutri",
@@ -319,6 +322,7 @@ OC.L10N.register(
     "Something went wrong" : "Prišlo je do napake ...",
     "Failed to upload {name}" : "Pošiljanje {name} je spodletelo",
     "Maximum file size of {size} exceeded" : "Omejitev velikosti datoteke {size} je prekoračena.",
+    "Due date" : "Datum preteka",
     "Error creating the share" : "Napaka ustvarjanja mesta souporabe",
     "Share with a Deck card" : "Poveži z nalogo Deck",
     "Share {file} with a Deck card" : "Poveži datoteko {file} z nalogo Deck",
