@@ -1,10 +1,11 @@
 OC.L10N.register(
     "deck",
     {
-    "Done" : "Done",
     "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "பதிவேற்றப்பட்ட கோப்பானது HTML  படிவத்தில் குறிப்பிடப்பட்டுள்ள MAX_FILE_SIZE  directive ஐ விட கூடியது",
     "No file was uploaded" : "எந்த கோப்பும் பதிவேற்றப்படவில்லை",
     "Missing a temporary folder" : "ஒரு தற்காலிகமான கோப்புறையை காணவில்லை",
+    "Done" : "Done",
+    "File" : "File",
     "Cancel" : "இரத்து செய்க",
     "Details" : "விவரங்கள்",
     "Tags" : "சீட்டுகள்",
@@ -17,13 +18,14 @@ OC.L10N.register(
     "Download" : "பதிவிறக்குக",
     "Modified" : "மாற்றப்பட்டது",
     "Save" : "சேமிக்க ",
-    "Update" : "இற்றைப்படுத்தல்",
     "Created:" : "உருவாக்கப்பட்டது:",
+    "Update" : "இற்றைப்படுத்தல்",
     "Description" : "விவரிப்பு",
     "seconds ago" : "செக்கன்களுக்கு முன்",
     "Keyboard shortcuts" : "விசைப்பலகை குறுக்குவழிகள்",
     "Search" : "தேடுதல்",
     "Shared with you" : "Shared with you",
+    "Export" : "ஏற்றுமதி",
     "Today" : "இன்று",
     "Close" : "மூடுக",
     "Share" : "பகிர்வு",
