@@ -1,10 +1,6 @@
 OC.L10N.register(
     "deck",
     {
-    "Finished" : "เสร็จสิ้น",
-    "copy" : "คัดลอก",
-    "In Progress" : "อยู่ระหว่างการดำเนินการ",
-    "Done" : "เสร็จสิ้น",
     "The file was uploaded" : "ไฟล์อัปโหลดแล้ว",
     "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "ขนาดไฟล์ที่อัปโหลดมีขนาดเกินค่า upload_max_filesize ที่ระบุไว้ใน php.ini",
     "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "ไฟล์ที่อัปโหลดมีขนาดใหญ่เกินค่า MAX_FILE_SIZE ที่ระบุไว้ในรูปแบบของ HTML",
@@ -13,6 +9,12 @@ OC.L10N.register(
     "Missing a temporary folder" : "โฟลเดอร์ชั่วคราวขาดหาย",
     "Could not write file to disk" : "ไม่สามารถเขียนไฟล์ลงดิสก์",
     "A PHP extension stopped the file upload" : "ส่วนขยาย PHP ได้หยุดการอัปโหลดไฟล์",
+    "Finished" : "เสร็จสิ้น",
+    "copy" : "คัดลอก",
+    "In Progress" : "อยู่ระหว่างการดำเนินการ",
+    "Done" : "เสร็จสิ้น",
+    "Attachments" : "ไฟล์แนบ",
+    "File" : "ไฟล์",
     "Card not found" : "ไม่พบการ์ด",
     "Invalid date, date format must be YYYY-MM-DD" : "วันที่ไม่ถูกต้อง รูปแบบวันที่จะต้องเป็น ปปปป-ดด-วว",
     "Cancel" : "ยกเลิก",
@@ -26,22 +28,21 @@ OC.L10N.register(
     "Tags" : "แท็ก",
     "Activity" : "กิจกรรม",
     "Undo" : "เลิกทำ",
+    "Transfer" : "โอนย้าย",
     "Can edit" : "สามารถแก้ไข",
     "Can share" : "สามารถแชร์",
     "Owner" : "เจ้าของ",
     "Delete" : "ลบ",
-    "Transfer" : "โอนย้าย",
     "Delete list" : "ลบรายการ",
     "Edit" : "แก้ไข",
-    "Download" : "ดาวน์โหลด",
     "Invalid path selected" : "เลือกเส้นทางไม่ถูกต้อง",
-    "Attachments" : "ไฟล์แนบ",
-    "Comments" : "ความคิดเห็น",
+    "Download" : "ดาวน์โหลด",
     "Modified" : "แก้ไขเมื่อ",
+    "Comments" : "ความคิดเห็น",
     "Save" : "บันทึก",
+    "Created:" : "สร้างเมื่อ:",
     "Reply" : "ตอบกลับ",
     "Update" : "อัปเดต",
-    "Created:" : "สร้างเมื่อ:",
     "Description" : "รายละเอียด",
     "(group)" : "(กลุ่ม)",
     "seconds ago" : "วินาทีที่ผ่านมา",
@@ -49,14 +50,16 @@ OC.L10N.register(
     "Keyboard shortcut" : "แป้นพิมพ์ลัด",
     "Search" : "ค้นหา",
     "Shared with you" : "แชร์กับคุณ",
+    "An error occurred" : "เกิดข้อผิดพลาด",
     "Edit board" : "แก้ไขกระดาน",
     "No notifications" : "ไม่มีการแจ้งเตือน",
     "Delete board" : "ลบกระดาน",
-    "An error occurred" : "เกิดข้อผิดพลาด",
     "Advanced options" : "ตัวเลือกขั้นสูง",
+    "Export" : "ส่งออก",
     "Today" : "วันนี้",
     "Tomorrow" : "พรุ่งนี้",
     "Close" : "ปิด",
+    "Due date" : "วันที่ครบกำหนด",
     "Share" : "แชร์",
     "Personal" : "ส่วนตัว"
 },
