@@ -1,26 +1,8 @@
 <?php
+
 /**
- * @copyright Copyright (c) 2018 Julius Härtl <jus@bitgrid.net>
- *
- * @copyright Copyright (c) 2019 Alexandru Puiu <alexpuiu20@yahoo.com>
- *
- * @author Julius Härtl <jus@bitgrid.net>
- *
- * @license GNU AGPL version 3 or any later version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
- *
+ * SPDX-FileCopyrightText: 2018 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 namespace OCA\Deck\Activity;
@@ -38,6 +20,7 @@ use OCA\Deck\Db\CardMapper;
 use OCA\Deck\Db\Label;
 use OCA\Deck\Db\Stack;
 use OCA\Deck\Db\StackMapper;
+use OCA\Deck\NoPermissionException;
 use OCA\Deck\Service\PermissionService;
 use OCP\Activity\IEvent;
 use OCP\Activity\IManager;
@@ -45,8 +28,8 @@ use OCP\AppFramework\Db\DoesNotExistException;
 use OCP\AppFramework\Db\MultipleObjectsReturnedException;
 use OCP\Comments\IComment;
 use OCP\IUser;
-use OCP\Server;
 use OCP\L10N\IFactory;
+use OCP\Server;
 use Psr\Log\LoggerInterface;
 
 class ActivityManager {
@@ -91,6 +74,8 @@ class ActivityManager {
 	public const SUBJECT_CARD_UPDATE_DUEDATE = 'card_update_duedate';
 	public const SUBJECT_CARD_UPDATE_ARCHIVE = 'card_update_archive';
 	public const SUBJECT_CARD_UPDATE_UNARCHIVE = 'card_update_unarchive';
+	public const SUBJECT_CARD_UPDATE_DONE = 'card_update_done';
+	public const SUBJECT_CARD_UPDATE_UNDONE = 'card_update_undone';
 	public const SUBJECT_CARD_UPDATE_STACKID = 'card_update_stackId';
 	public const SUBJECT_CARD_USER_ASSIGN = 'card_user_assign';
 	public const SUBJECT_CARD_USER_UNASSIGN = 'card_user_unassign';
@@ -116,7 +101,7 @@ class ActivityManager {
 		StackMapper $stackMapper,
 		AclMapper $aclMapper,
 		IFactory $l10nFactory,
-		?string $userId
+		?string $userId,
 	) {
 		$this->manager = $manager;
 		$this->permissionService = $permissionsService;
@@ -198,6 +183,12 @@ class ActivityManager {
 			case self::SUBJECT_CARD_UPDATE_UNARCHIVE:
 				$subject = $ownActivity ? $l->t('You have unarchived card {card} in list {stack} on board {board}') : $l->t('{user} has unarchived card {card} in list {stack} on board {board}');
 				break;
+			case self::SUBJECT_CARD_UPDATE_DONE:
+				$subject = $ownActivity ? $l->t('You have marked the card {card} as done in list {stack} on board {board}') : $l->t('{user} has marked card {card} as done in list {stack} on board {board}');
+				break;
+			case self::SUBJECT_CARD_UPDATE_UNDONE:
+				$subject = $ownActivity ? $l->t('You have marked the card {card} as undone in list {stack} on board {board}') : $l->t('{user} has marked the card {card} as undone in list {stack} on board {board}');
+				break;
 			case self::SUBJECT_CARD_UPDATE_DUEDATE:
 				if (!isset($subjectParams['after'])) {
 					$subject = $ownActivity ? $l->t('You have removed the due date of card {card}') : $l->t('{user} has removed the due date of card {card}');
@@ -332,8 +323,8 @@ class ActivityManager {
 			case self::SUBJECT_BOARD_UPDATE_ARCHIVED:
 			case self::SUBJECT_BOARD_DELETE:
 			case self::SUBJECT_BOARD_RESTORE:
-			// Not defined as there is no activity for
-			// case self::SUBJECT_BOARD_UPDATE_COLOR
+				// Not defined as there is no activity for
+				// case self::SUBJECT_BOARD_UPDATE_COLOR
 				break;
 			case self::SUBJECT_CARD_COMMENT_CREATE:
 				$eventType = 'deck_comment';
@@ -357,6 +348,8 @@ class ActivityManager {
 			case self::SUBJECT_CARD_DELETE:
 			case self::SUBJECT_CARD_UPDATE_ARCHIVE:
 			case self::SUBJECT_CARD_UPDATE_UNARCHIVE:
+			case self::SUBJECT_CARD_UPDATE_DONE:
+			case self::SUBJECT_CARD_UPDATE_UNDONE:
 			case self::SUBJECT_CARD_UPDATE_TITLE:
 			case self::SUBJECT_CARD_UPDATE_DESCRIPTION:
 			case self::SUBJECT_CARD_UPDATE_DUEDATE:
@@ -374,7 +367,7 @@ class ActivityManager {
 					$additionalParams['before'] = $additionalParams['before']->format('c');
 				}
 
-			break;
+				break;
 			case self::SUBJECT_ATTACHMENT_CREATE:
 			case self::SUBJECT_ATTACHMENT_UPDATE:
 			case self::SUBJECT_ATTACHMENT_DELETE:
@@ -492,7 +485,7 @@ class ActivityManager {
 					$objectId = $entity->getObjectId();
 					break;
 				default:
-					throw new InvalidArgumentException('No entity relation present for '. $className . ' to ' . $objectType);
+					throw new InvalidArgumentException('No entity relation present for ' . $className . ' to ' . $objectType);
 			}
 			return $this->cardMapper->find($objectId);
 		}
@@ -507,11 +500,11 @@ class ActivityManager {
 					$objectId = $entity->getBoardId();
 					break;
 				default:
-					throw new InvalidArgumentException('No entity relation present for '. $className . ' to ' . $objectType);
+					throw new InvalidArgumentException('No entity relation present for ' . $className . ' to ' . $objectType);
 			}
 			return $this->boardMapper->find($objectId);
 		}
-		throw new InvalidArgumentException('No entity relation present for '. $className . ' to ' . $objectType);
+		throw new InvalidArgumentException('No entity relation present for ' . $className . ' to ' . $objectType);
 	}
 
 	private function findDetailsForStack($stackId) {
@@ -554,4 +547,24 @@ class ActivityManager {
 			'board' => $board
 		];
 	}
+
+	public function canSeeCardActivity(int $cardId, string $userId): bool {
+		try {
+			$this->permissionService->checkPermission($this->cardMapper, $cardId, Acl::PERMISSION_READ, $userId);
+			$card = $this->cardMapper->find($cardId);
+			return $card->getDeletedAt() === 0;
+		} catch (NoPermissionException $e) {
+			return false;
+		}
+	}
+
+	public function canSeeBoardActivity(int $boardId, string $userId): bool {
+		try {
+			$this->permissionService->checkPermission($this->boardMapper, $boardId, Acl::PERMISSION_READ, $userId);
+			$board = $this->boardMapper->find($boardId);
+			return $board->getDeletedAt() === 0;
+		} catch (NoPermissionException $e) {
+			return false;
+		}
+	}
 }
