@@ -1,25 +1,8 @@
 <?php
+
 /**
- * @copyright Copyright (c) 2016 Julius Härtl <jus@bitgrid.net>
- *
- * @author Julius Härtl <jus@bitgrid.net>
- * @author Maxence Lange <maxence@artificial-owl.com>
- *
- * @license GNU AGPL version 3 or any later version
- *
- *  This program is free software: you can redistribute it and/or modify
- *  it under the terms of the GNU Affero General Public License as
- *  published by the Free Software Foundation, either version 3 of the
- *  License, or (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Affero General Public License for more details.
- *
- *  You should have received a copy of the GNU Affero General Public License
- *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
+ * SPDX-FileCopyrightText: 2016 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 namespace OCA\Deck\Service;
@@ -27,13 +10,18 @@ namespace OCA\Deck\Service;
 use OCA\Deck\Activity\ActivityManager;
 use OCA\Deck\Activity\ChangeSet;
 use OCA\Deck\AppInfo\Application;
+use OCA\Deck\BadRequestException;
 use OCA\Deck\Db\Acl;
 use OCA\Deck\Db\AclMapper;
 use OCA\Deck\Db\AssignmentMapper;
+use OCA\Deck\Db\Board;
+use OCA\Deck\Db\BoardMapper;
+use OCA\Deck\Db\Card;
 use OCA\Deck\Db\CardMapper;
 use OCA\Deck\Db\ChangeHelper;
 use OCA\Deck\Db\IPermissionMapper;
 use OCA\Deck\Db\Label;
+use OCA\Deck\Db\LabelMapper;
 use OCA\Deck\Db\Session;
 use OCA\Deck\Db\SessionMapper;
 use OCA\Deck\Db\Stack;
@@ -41,94 +29,48 @@ use OCA\Deck\Db\StackMapper;
 use OCA\Deck\Event\AclCreatedEvent;
 use OCA\Deck\Event\AclDeletedEvent;
 use OCA\Deck\Event\AclUpdatedEvent;
+use OCA\Deck\Event\BoardUpdatedEvent;
+use OCA\Deck\Event\CardCreatedEvent;
 use OCA\Deck\NoPermissionException;
 use OCA\Deck\Notification\NotificationHelper;
+use OCA\Deck\Validators\BoardServiceValidator;
 use OCP\AppFramework\Db\DoesNotExistException;
 use OCP\AppFramework\Db\MultipleObjectsReturnedException;
+use OCP\DB\Exception as DbException;
 use OCP\EventDispatcher\IEventDispatcher;
 use OCP\IConfig;
 use OCP\IDBConnection;
-use OCP\IGroupManager;
 use OCP\IL10N;
-use OCP\DB\Exception as DbException;
-use OCA\Deck\Db\Board;
-use OCA\Deck\Db\BoardMapper;
-use OCA\Deck\Db\LabelMapper;
-use OCP\IUserManager;
-use OCA\Deck\BadRequestException;
-use OCA\Deck\Event\BoardUpdatedEvent;
-use OCA\Deck\Validators\BoardServiceValidator;
 use OCP\IURLGenerator;
 use OCP\Server;
 use Psr\Container\ContainerExceptionInterface;
 use Psr\Container\NotFoundExceptionInterface;
 
 class BoardService {
-	private BoardMapper $boardMapper;
-	private StackMapper $stackMapper;
-	private LabelMapper $labelMapper;
-	private AclMapper $aclMapper;
-	private IConfig $config;
-	private IL10N $l10n;
-	private PermissionService $permissionService;
-	private NotificationHelper $notificationHelper;
-	private AssignmentMapper $assignedUsersMapper;
-	private IUserManager $userManager;
-	private IGroupManager $groupManager;
-	private ?string $userId;
-	private ActivityManager $activityManager;
-	private IEventDispatcher $eventDispatcher;
-	private ChangeHelper $changeHelper;
-	private CardMapper $cardMapper;
 	private ?array $boardsCacheFull = null;
 	private ?array $boardsCachePartial = null;
-	private IURLGenerator $urlGenerator;
-	private IDBConnection $connection;
-	private BoardServiceValidator $boardServiceValidator;
-	private SessionMapper $sessionMapper;
 
 	public function __construct(
-		BoardMapper $boardMapper,
-		StackMapper $stackMapper,
-		CardMapper $cardMapper,
-		IConfig $config,
-		IL10N $l10n,
-		LabelMapper $labelMapper,
-		AclMapper $aclMapper,
-		PermissionService $permissionService,
-		NotificationHelper $notificationHelper,
-		AssignmentMapper $assignedUsersMapper,
-		IUserManager $userManager,
-		IGroupManager $groupManager,
-		ActivityManager $activityManager,
-		IEventDispatcher $eventDispatcher,
-		ChangeHelper $changeHelper,
-		IURLGenerator $urlGenerator,
-		IDBConnection $connection,
-		BoardServiceValidator $boardServiceValidator,
-		SessionMapper $sessionMapper,
-		?string $userId
+		private BoardMapper $boardMapper,
+		private StackMapper $stackMapper,
+		private CardMapper $cardMapper,
+		private IConfig $config,
+		private IL10N $l10n,
+		private LabelMapper $labelMapper,
+		private AclMapper $aclMapper,
+		private PermissionService $permissionService,
+		private AssignmentService $assignmentService,
+		private NotificationHelper $notificationHelper,
+		private AssignmentMapper $assignedUsersMapper,
+		private ActivityManager $activityManager,
+		private IEventDispatcher $eventDispatcher,
+		private ChangeHelper $changeHelper,
+		private IURLGenerator $urlGenerator,
+		private IDBConnection $connection,
+		private BoardServiceValidator $boardServiceValidator,
+		private SessionMapper $sessionMapper,
+		private ?string $userId,
 	) {
-		$this->boardMapper = $boardMapper;
-		$this->stackMapper = $stackMapper;
-		$this->cardMapper = $cardMapper;
-		$this->labelMapper = $labelMapper;
-		$this->config = $config;
-		$this->aclMapper = $aclMapper;
-		$this->l10n = $l10n;
-		$this->permissionService = $permissionService;
-		$this->notificationHelper = $notificationHelper;
-		$this->assignedUsersMapper = $assignedUsersMapper;
-		$this->userManager = $userManager;
-		$this->groupManager = $groupManager;
-		$this->activityManager = $activityManager;
-		$this->eventDispatcher = $eventDispatcher;
-		$this->changeHelper = $changeHelper;
-		$this->userId = $userId;
-		$this->urlGenerator = $urlGenerator;
-		$this->connection = $connection;
-		$this->boardServiceValidator = $boardServiceValidator;
-		$this->sessionMapper = $sessionMapper;
 	}
 
 	/**
@@ -145,7 +87,7 @@ class BoardService {
 	 * Get all boards that are shared with a user, their groups or circles
 	 */
 	public function getUserBoards(?int $since = null, bool $includeArchived = true, ?int $before = null,
-								  ?string $term = null): array {
+		?string $term = null): array {
 		return $this->boardMapper->findAllForUser($this->userId, $since, $includeArchived, $before, $term);
 	}
 
@@ -153,25 +95,17 @@ class BoardService {
 	 * @return Board[]
 	 */
 	public function findAll(int $since = -1, bool $fullDetails = false, bool $includeArchived = true): array {
-		if ($this->boardsCacheFull && $fullDetails) {
-			return $this->boardsCacheFull;
-		}
-
-		if ($this->boardsCachePartial && !$fullDetails) {
-			return $this->boardsCachePartial;
-		}
-
 		$complete = $this->getUserBoards($since, $includeArchived);
 		return $this->enrichBoards($complete, $fullDetails);
 	}
 
 	/**
 	 * @throws DoesNotExistException
-	 * @throws \OCA\Deck\NoPermissionException
+	 * @throws NoPermissionException
 	 * @throws \OCP\AppFramework\Db\MultipleObjectsReturnedException
 	 * @throws BadRequestException
 	 */
-	public function find(int $boardId, bool $fullDetails = true): Board {
+	public function find(int $boardId, bool $fullDetails = true, bool $allowDeleted = false): Board {
 		$this->boardServiceValidator->check(compact('boardId'));
 
 		if (isset($this->boardsCacheFull[$boardId]) && $fullDetails) {
@@ -184,7 +118,7 @@ class BoardService {
 
 		$this->permissionService->checkPermission($this->boardMapper, $boardId, Acl::PERMISSION_READ);
 		/** @var Board $board */
-		$board = $this->boardMapper->find($boardId, true, true);
+		$board = $this->boardMapper->find($boardId, true, true, $allowDeleted);
 		[$board] = $this->enrichBoards([$board], $fullDetails);
 		return $board;
 	}
@@ -194,7 +128,7 @@ class BoardService {
 	 * @param $id
 	 * @return bool
 	 * @throws DoesNotExistException
-	 * @throws \OCA\Deck\NoPermissionException
+	 * @throws NoPermissionException
 	 * @throws \OCP\AppFramework\Db\MultipleObjectsReturnedException
 	 * @throws BadRequestException
 	 */
@@ -221,7 +155,7 @@ class BoardService {
 	 * @param $id
 	 * @return bool
 	 * @throws DoesNotExistException
-	 * @throws \OCA\Deck\NoPermissionException
+	 * @throws NoPermissionException
 	 * @throws \OCP\AppFramework\Db\MultipleObjectsReturnedException
 	 * @throws BadRequestException
 	 */
@@ -298,7 +232,7 @@ class BoardService {
 	 * @param $id
 	 * @return Board
 	 * @throws DoesNotExistException
-	 * @throws \OCA\Deck\NoPermissionException
+	 * @throws NoPermissionException
 	 * @throws \OCP\AppFramework\Db\MultipleObjectsReturnedException
 	 * @throws BadRequestException
 	 */
@@ -322,14 +256,14 @@ class BoardService {
 	 * @param $id
 	 * @return \OCP\AppFramework\Db\Entity
 	 * @throws DoesNotExistException
-	 * @throws \OCA\Deck\NoPermissionException
+	 * @throws NoPermissionException
 	 * @throws \OCP\AppFramework\Db\MultipleObjectsReturnedException
 	 */
 	public function deleteUndo($id) {
 		$this->boardServiceValidator->check(compact('id'));
 
 		$this->permissionService->checkPermission($this->boardMapper, $id, Acl::PERMISSION_MANAGE);
-		$board = $this->find($id);
+		$board = $this->find($id, allowDeleted: true);
 		$board->setDeletedAt(0);
 		$board = $this->boardMapper->update($board);
 		$this->activityManager->triggerEvent(ActivityManager::DECK_OBJECT_BOARD, $board, ActivityManager::SUBJECT_BOARD_RESTORE);
@@ -342,7 +276,7 @@ class BoardService {
 	 * @param $id
 	 * @return \OCP\AppFramework\Db\Entity
 	 * @throws DoesNotExistException
-	 * @throws \OCA\Deck\NoPermissionException
+	 * @throws NoPermissionException
 	 * @throws \OCP\AppFramework\Db\MultipleObjectsReturnedException
 	 * @throws BadRequestException
 	 */
@@ -350,7 +284,7 @@ class BoardService {
 		$this->boardServiceValidator->check(compact('id'));
 
 		$this->permissionService->checkPermission($this->boardMapper, $id, Acl::PERMISSION_MANAGE);
-		$board = $this->find($id);
+		$board = $this->find($id, allowDeleted: true);
 		$delete = $this->boardMapper->delete($board);
 
 		return $delete;
@@ -363,7 +297,7 @@ class BoardService {
 	 * @param $archived
 	 * @return \OCP\AppFramework\Db\Entity
 	 * @throws DoesNotExistException
-	 * @throws \OCA\Deck\NoPermissionException
+	 * @throws NoPermissionException
 	 * @throws \OCP\AppFramework\Db\MultipleObjectsReturnedException
 	 * @throws BadRequestException
 	 */
@@ -386,14 +320,14 @@ class BoardService {
 		return $board;
 	}
 
-	private function applyPermissions($boardId, $edit, $share, $manage) {
+	private function applyPermissions($boardId, $edit, $share, $manage, $oldAcl = null) {
 		try {
 			$this->permissionService->checkPermission($this->boardMapper, $boardId, Acl::PERMISSION_MANAGE);
 		} catch (NoPermissionException $e) {
 			$acls = $this->aclMapper->findAll($boardId);
-			$edit = $this->permissionService->userCan($acls, Acl::PERMISSION_EDIT, $this->userId) && $edit;
-			$share = $this->permissionService->userCan($acls, Acl::PERMISSION_SHARE, $this->userId) && $share;
-			$manage = $this->permissionService->userCan($acls, Acl::PERMISSION_MANAGE, $this->userId) && $manage;
+			$edit = $this->permissionService->userCan($acls, Acl::PERMISSION_EDIT, $this->userId) ? $edit : $oldAcl?->getPermissionEdit() ?? false;
+			$share = $this->permissionService->userCan($acls, Acl::PERMISSION_SHARE, $this->userId) ? $share : $oldAcl?->getPermissionShare() ?? false;
+			$manage = $this->permissionService->userCan($acls, Acl::PERMISSION_MANAGE, $this->userId) ? $manage : $oldAcl?->getPermissionManage() ?? false;
 		}
 		return [$edit, $share, $manage];
 	}
@@ -428,7 +362,7 @@ class BoardService {
 	 * @param $manage
 	 * @return \OCP\AppFramework\Db\Entity
 	 * @throws BadRequestException
-	 * @throws \OCA\Deck\NoPermissionException
+	 * @throws NoPermissionException
 	 */
 	public function addAcl($boardId, $type, $participant, $edit, $share, $manage) {
 		$this->boardServiceValidator->check(compact('boardId', 'type', 'participant', 'edit', 'share', 'manage'));
@@ -446,7 +380,7 @@ class BoardService {
 		$newAcl = $this->aclMapper->insert($acl);
 
 		$this->activityManager->triggerEvent(ActivityManager::DECK_OBJECT_BOARD, $newAcl, ActivityManager::SUBJECT_BOARD_SHARE, [], $this->userId);
-		$this->notificationHelper->sendBoardShared((int)$boardId, $acl);
+		$this->notificationHelper->sendBoardShared($boardId, $acl);
 		$this->boardMapper->mapAcl($newAcl);
 		$this->changeHelper->boardChanged($boardId);
 
@@ -472,7 +406,7 @@ class BoardService {
 	 * @param $manage
 	 * @return \OCP\AppFramework\Db\Entity
 	 * @throws DoesNotExistException
-	 * @throws \OCA\Deck\NoPermissionException
+	 * @throws NoPermissionException
 	 * @throws \OCP\AppFramework\Db\MultipleObjectsReturnedException
 	 * @throws BadRequestException
 	 */
@@ -483,7 +417,7 @@ class BoardService {
 
 		/** @var Acl $acl */
 		$acl = $this->aclMapper->find($id);
-		[$edit, $share, $manage] = $this->applyPermissions($acl->getBoardId(), $edit, $share, $manage);
+		[$edit, $share, $manage] = $this->applyPermissions($acl->getBoardId(), $edit, $share, $manage, $acl);
 		$acl->setPermissionEdit($edit);
 		$acl->setPermissionShare($share);
 		$acl->setPermissionManage($manage);
@@ -505,15 +439,12 @@ class BoardService {
 	 * @throws NotFoundExceptionInterface
 	 */
 	public function deleteAcl(int $id): ?Acl {
-		$this->permissionService->checkPermission($this->aclMapper, $id, Acl::PERMISSION_SHARE);
+		$this->permissionService->checkPermission($this->aclMapper, $id, Acl::PERMISSION_MANAGE);
 		/** @var Acl $acl */
 		$acl = $this->aclMapper->find($id);
 		$this->boardMapper->mapAcl($acl);
 		if ($acl->getType() === Acl::PERMISSION_TYPE_USER) {
-			$assignements = $this->assignedUsersMapper->findByParticipant($acl->getParticipant());
-			foreach ($assignements as $assignement) {
-				$this->assignedUsersMapper->delete($assignement);
-			}
+			$this->assignedUsersMapper->deleteByParticipantOnBoard($acl->getParticipant(), $acl->getBoardId());
 		}
 
 		$this->activityManager->triggerEvent(ActivityManager::DECK_OBJECT_BOARD, $acl, ActivityManager::SUBJECT_BOARD_UNSHARE);
@@ -536,17 +467,22 @@ class BoardService {
 	}
 
 	/**
-	 * @param $id
-	 * @param $userId
-	 * @return Board
-	 * @throws DoesNotExistException
-	 * @throws \OCA\Deck\NoPermissionException
-	 * @throws \OCP\AppFramework\Db\MultipleObjectsReturnedException
 	 * @throws BadRequestException
+	 * @throws DbException
+	 * @throws DoesNotExistException
+	 * @throws MultipleObjectsReturnedException
+	 * @throws NoPermissionException
 	 */
-	public function clone($id, $userId) {
+	public function clone(
+		int $id, string $userId,
+		bool $withCards = false, bool $withAssignments = false, bool $withLabels = false, bool $withDueDate = false, bool $moveCardsToLeftStack = false, bool $restoreArchivedCards = false,
+	): Board {
 		$this->boardServiceValidator->check(compact('id', 'userId'));
 
+		if (!$this->permissionService->canCreate()) {
+			throw new NoPermissionException('Creating boards has been disabled for your account.');
+		}
+
 		$this->permissionService->checkPermission($this->boardMapper, $id, Acl::PERMISSION_READ);
 
 		$board = $this->boardMapper->find($id);
@@ -563,6 +499,16 @@ class BoardService {
 		]);
 		$this->boardMapper->insert($newBoard);
 
+		foreach ($this->aclMapper->findAll($board->getId()) as $acl) {
+			$this->addAcl($newBoard->getId(),
+				$acl->getType(),
+				$acl->getParticipant(),
+				$acl->getPermissionEdit(),
+				$acl->getPermissionShare(),
+				$acl->getPermissionManage());
+		}
+
+
 		$labels = $this->labelMapper->findAll($id);
 		foreach ($labels as $label) {
 			$newLabel = new Label();
@@ -576,10 +522,19 @@ class BoardService {
 		foreach ($stacks as $stack) {
 			$newStack = new Stack();
 			$newStack->setTitle($stack->getTitle());
+			if ($stack->getOrder() == null) {
+				$newStack->setOrder(999);
+			} else {
+				$newStack->setOrder($stack->getOrder());
+			}
 			$newStack->setBoardId($newBoard->getId());
 			$this->stackMapper->insert($newStack);
 		}
 
+		if ($withCards) {
+			$this->cloneCards($board, $newBoard, $withAssignments, $withLabels, $withDueDate, $moveCardsToLeftStack, $restoreArchivedCards);
+		}
+
 		return $this->find($newBoard->getId());
 	}
 
@@ -627,7 +582,7 @@ class BoardService {
 	 * @param $id
 	 * @return Board
 	 * @throws DoesNotExistException
-	 * @throws \OCA\Deck\NoPermissionException
+	 * @throws NoPermissionException
 	 * @throws \OCP\AppFramework\Db\MultipleObjectsReturnedException
 	 * @throws BadRequestException
 	 */
@@ -637,7 +592,7 @@ class BoardService {
 		}
 
 		$this->permissionService->checkPermission($this->boardMapper, $id, Acl::PERMISSION_READ);
-		$board = $this->boardMapper->find($id);
+		$board = $this->boardMapper->find((int)$id);
 		$this->enrichWithCards($board);
 		$this->enrichWithLabels($board);
 
@@ -683,6 +638,83 @@ class BoardService {
 		return $boards;
 	}
 
+	private function cloneCards(Board $board, Board $newBoard, bool $withAssignments = false, bool $withLabels = false, bool $withDueDate = false, bool $moveCardsToLeftStack = false, bool $restoreArchivedCards = false): void {
+		$stacks = $this->stackMapper->findAll($board->getId());
+		$newStacks = $this->stackMapper->findAll($newBoard->getId());
+
+		$stackSorter = function (Stack $a, Stack $b) {
+			return $a->getOrder() - $b->getOrder();
+		};
+		usort($stacks, $stackSorter);
+		usort($newStacks, $stackSorter);
+
+		$i = 0;
+		foreach ($stacks as $stack) {
+			$cards = $this->cardMapper->findAll($stack->getId());
+			$archivedCards = $this->cardMapper->findAllArchived($stack->getId());
+
+			/** @var Card[] $cards */
+			$cards = array_merge($cards, $archivedCards);
+
+			foreach ($cards as $card) {
+				$targetStackId = $moveCardsToLeftStack ? $newStacks[0]->getId() : $newStacks[$i]->getId();
+
+				// Create a cloned card.
+				// Done with setters as only fields set via setters get written to db
+				$newCard = new Card();
+				$newCard->setTitle($card->getTitle());
+				$newCard->setDescription($card->getDescription());
+				$newCard->setStackId($targetStackId);
+				$newCard->setType($card->getType());
+				$newCard->setOwner($card->getOwner());
+				$newCard->setOrder($card->getOrder());
+				$newCard->setDuedate($withDueDate ? $card->getDuedate() : null);
+				$newCard->setArchived($restoreArchivedCards ? false : $card->getArchived());
+				$newCard->setStackId($targetStackId);
+
+				// Persist the cloned card.
+				$newCard = $this->cardMapper->insert($newCard);
+
+
+				// Copy labels.
+				if ($withLabels) {
+					$labels = $this->labelMapper->findAssignedLabelsForCard($card->getId());
+					$newLabels = $this->labelMapper->findAll($newBoard->getId());
+					$newLabelTitles = [];
+					foreach ($newLabels as $label) {
+						$newLabelTitles[$label->getTitle()] = $label;
+					}
+
+					foreach ($labels as $label) {
+						$newLabelId = $newLabelTitles[$label->getTitle()]?->getId() ?? null;
+						if ($newLabelId) {
+							$this->cardMapper->assignLabel($newCard->getId(), $newLabelId);
+						}
+					}
+				}
+
+
+				// Copy assignments.
+				if ($withAssignments) {
+					$assignments = $this->assignedUsersMapper->findAll($card->getId());
+
+					foreach ($assignments as $assignment) {
+						$this->assignmentService->assignUser($newCard->getId(), $assignment->getParticipant(), $assignment->getType());
+					}
+				}
+
+				// Known limitation: Currently we do not copy attachments or comments
+
+				// Copied from CardService because CardService cannot be injected due to cyclic dependencies.
+				$this->activityManager->triggerEvent(ActivityManager::DECK_OBJECT_CARD, $card, ActivityManager::SUBJECT_CARD_CREATE);
+				$this->changeHelper->cardChanged($card->getId(), false);
+				$this->eventDispatcher->dispatchTyped(new CardCreatedEvent($card));
+			}
+
+			$i++;
+		}
+	}
+
 	private function enrichWithStacks($board, $since = -1) {
 		$stacks = $this->stackMapper->findAll($board->getId(), null, null, $since);
 
@@ -711,10 +743,6 @@ class BoardService {
 		$board->setUsers(array_values($boardUsers));
 	}
 
-	public function getBoardUrl($endpoint) {
-		return $this->urlGenerator->linkToRouteAbsolute('deck.page.index') . '#' . $endpoint;
-	}
-
 	/**
 	 * Clean a given board data from the Cache
 	 */
