@@ -1,4 +1,5 @@
 <?php
+
 /**
  * SPDX-FileCopyrightText: 2020 Nextcloud GmbH and Nextcloud contributors
  * SPDX-License-Identifier: AGPL-3.0-or-later
@@ -69,7 +70,7 @@ class DeckShareProvider implements \OCP\Share\IShareProvider {
 		IL10N $l,
 		ITimeFactory $timeFactory,
 		IMimeTypeLoader $mimeTypeLoader,
-		?string $userId
+		?string $userId,
 	) {
 		$this->dbConnection = $connection;
 		$this->shareManager = $shareManager;
@@ -110,7 +111,7 @@ class DeckShareProvider implements \OCP\Share\IShareProvider {
 		try {
 			$board = $this->boardMapper->find($boardId);
 			$valid = $valid && !$board->getArchived();
-		} catch (DoesNotExistException | MultipleObjectsReturnedException $e) {
+		} catch (DoesNotExistException|MultipleObjectsReturnedException $e) {
 			$valid = false;
 		}
 
@@ -174,7 +175,7 @@ class DeckShareProvider implements \OCP\Share\IShareProvider {
 		string $target,
 		int $permissions,
 		string $token,
-		?\DateTime $expirationDate
+		?\DateTime $expirationDate,
 	): int {
 		$qb = $this->dbConnection->getQueryBuilder();
 		$qb->insert('share')
@@ -269,7 +270,7 @@ class DeckShareProvider implements \OCP\Share\IShareProvider {
 
 	private function applyBoardPermission($share, $permissions, $userId) {
 		try {
-			$this->permissionService->checkPermission($this->cardMapper, $share->getSharedWith(), Acl::PERMISSION_EDIT, $userId);
+			$this->permissionService->checkPermission($this->cardMapper, $share->getSharedWith(), Acl::PERMISSION_EDIT, $userId, true);
 		} catch (NoPermissionException $e) {
 			$permissions &= Constants::PERMISSION_ALL - Constants::PERMISSION_UPDATE;
 			$permissions &= Constants::PERMISSION_ALL - Constants::PERMISSION_CREATE;
@@ -277,7 +278,7 @@ class DeckShareProvider implements \OCP\Share\IShareProvider {
 		}
 
 		try {
-			$this->permissionService->checkPermission($this->cardMapper, $share->getSharedWith(), Acl::PERMISSION_SHARE, $userId);
+			$this->permissionService->checkPermission($this->cardMapper, $share->getSharedWith(), Acl::PERMISSION_SHARE, $userId, true);
 		} catch (NoPermissionException $e) {
 			$permissions &= Constants::PERMISSION_ALL - Constants::PERMISSION_SHARE;
 		}
@@ -746,6 +747,8 @@ class DeckShareProvider implements \OCP\Share\IShareProvider {
 					$qb->expr()->eq('s.item_type', $qb->createNamedParameter('folder'))
 				));
 
+			$qb->andWhere($qb->expr()->eq('dc.deleted_at', $qb->createNamedParameter(0, IQueryBuilder::PARAM_INT)));
+
 			$cursor = $qb->execute();
 			while ($data = $cursor->fetch()) {
 				if (!$this->isAccessibleResult($data)) {
@@ -966,8 +969,8 @@ class DeckShareProvider implements \OCP\Share\IShareProvider {
 	protected function filterSharesOfUser(array $shares): array {
 		// Deck shares when the user has a share exception
 		foreach ($shares as $id => $share) {
-			$type = (int) $share['share_type'];
-			$permissions = (int) $share['permissions'];
+			$type = (int)$share['share_type'];
+			$permissions = (int)$share['permissions'];
 
 			if ($type === self::SHARE_TYPE_DECK_USER) {
 				unset($shares[$share['parent']]);
